@@ -33,7 +33,7 @@ relevant aspects of the application being represented.
 """
 __docformat__ = 'reStructuredText'
 
-__version__ = '2.1.2 version (SVN $Revision: 3719 $)'
+__version__ = '2.1.3 version (SVN $Revision: 3733 $)'
 
 
 import copy
@@ -1383,7 +1383,7 @@ class Application(Task):
         if self.requested_cores > 1:
             qsub += ['-l', 'nodes=%d' % self.requested_cores]
         if 'jobname' in self and self.jobname:
-            qsub += ['-N', '"%s"' % self.jobname]
+            qsub += ['-N', '"%s"' % self.jobname[:15]]
         return (qsub, self.cmdline(resource))
 
 
